@@ -31,7 +31,8 @@ def get_ASTROMER(num_layers=2,
                  no_train=True,
                  maxlen=100,
                  batch_size=None,
-                 pretrained_weights=False):
+                 pretrained_weights=False,
+                 overwrite=True):
     if pretrained_weights:
         #model = load_weights(git_link="https://github.com/HarshVardhanGoyal/test_model.git", model_name="astromer_10022021")
         model_name="astromer_10022021"
@@ -79,7 +80,7 @@ def get_ASTROMER(num_layers=2,
 
         # Loading the model
         if os.path.isdir(model_path):
-            model = model.load_weights(destinationpath+"/")
+            model = model.load_weights(os.path.join(destinationpath, "weights"))
 
     else:
         serie  = Input(shape=(maxlen, 1),
