@@ -60,39 +60,39 @@ def standardize(tensor, axis=0, return_mean=False):
 
 def load_weights(git_link , model_name, overwrite=True):
     
-    # Creating a temporary directory and getting the saved weights
+    model_name="astromer_10022021"
+            git_link="https://github.com/HarshVardhanGoyal/test_model.git"
+            model_path = os.path.join(os.getcwd(),"weights")
+        
+            try: 
+                test_dir = tempfile.mkdtemp()
+                git.Repo.clone_from(git_link, test_dir, branch='main', depth=1)
+                time.sleep(2)
+                if os.path.isdir(model_path):
+                    if overwrite:
+                        shutil.rmtree(model_path)
+                    else:
+                        print("The saved weights already exists")
+            except:
+                print("Couldn't load the model")
+            finally:
+                sourcepath = os.path.join(test_dir, model_name)
+                sourcefiles = os.listdir(sourcepath)
+                destinationpath = os.path.join(model_path, model_name)
+                os.makedirs(destinationpath)
+                for file in sourcefiles:
+                    if file.endswith('.index') or file.endswith('.data-00000-of-00001') or file.endswith('.json') or file.endswith("checkpoint"):
+                        print(sourcefiles)
+                        print(destinationpath)
+                        print(file)
+                        shutil.move(os.path.join(sourcepath,file), os.path.join(destinationpath,file))
 
-    model_path = os.path.join(os.getcwd(),"weights")
-    
-    try: 
-        test_dir = tempfile.mkdtemp()
-        git.Repo.clone_from(git_link, test_dir, branch='main', depth=1)
-        if os.path.isdir(model_path):
-            if overwrite:
-                shutil.rmtree(model_path)
-            else:
-                print("The saved weights already exists")
-    except:
-        print("Couldn't load the model")
-    finally:
-        os.mkdir(model_path)
-        shutil.move(os.path.join(test_dir, model_name), model_path)
-    # shutil.rmtree(test_dir)
+            #shutil.move(os.path.join(test_dir, model_name), model_path)
+            # shutil.rmtree(test_dir)
 
-    conf_file = os.path.join( model_path, model_name, 'conf.json')
-    with open(conf_file, 'r') as handle:
-        conf = json.load(handle)
 
-    model = get_ASTROMER(num_layers=conf['layers'],
-                         d_model   =conf['head_dim'],
-                         num_heads =conf['heads'],
-                         dff       =conf['dff'],
-                         base      =conf['base'],
-                         dropout   =conf['dropout'],
-                         maxlen    =conf['max_obs'],
-                         use_leak  =conf['use_leak'])
 
-    # Loading the model
-    if os.path.isdir(model_path):
-        model = model.load_weights(model_path)
+            # Loading the model
+            if os.path.isdir(model_path):
+                model = model.load_weights(os.path.join(destinationpath, "weights"))
     return model
\ No newline at end of file
